<?php

namespace Drupal\funnelback\Twig\Extention;

use Drupal\funnelback\FunnelbackQueryString;
use Twig\Extension\AbstractExtension;
use Twig\TwigFunction;

/**
 * Twig extension for the Funnelback module.
 *
 * Provides functions to generate Funnelback-related URLs and links.
 */
class FunnelbackTwigExtension extends AbstractExtension {

  /**
   * {@inheritdoc}
   */
  public function getName() {
    return 'funnelback_filter_query_string';
  }

  /**
   * Function declarations.
   *
   * @return \Twig\TwigFunction[]
   *   List of supported Twig functions for this extension.
   */
  public function getFunctions() {
    return [
      new TwigFunction('funnelback_filter_query_string', $this->funnelbackFilterQueryString(...)),
      new TwigFunction('funnelback_filter_curator_link', $this->funnelbackFilterCuratorLink(...)),
    ];
  }

  /**
   * Filter query string.
   *
   * @param mixed $queryString
   *   Query string.
   *
   * @return string
   *   The filtered query string.
   */
  public function funnelbackFilterQueryString($queryString): string {
    return FunnelbackQueryString::filterQueryString($queryString ?? '');
  }

  /**
   * Filter query string.
   *
   * @param mixed $linkUrl
   *   Link URL.
   *
   * @return string
   *   Formatted link.
   */
  public function funnelbackFilterCuratorLink($linkUrl): string {
    return FunnelbackQueryString::filterCuratorLink($linkUrl ?? '');
  }

}
